import { createApp } from 'vue'
import App from './App.vue'
import router from './router'

import ZDecoratorView from 'z-decorator-view'
import 'z-decorator-view/src/style.css'

import { useProfileStore } from './store/profileStore'
import { Constant } from './models/Constant'
import { ElNotification } from 'element-plus'

import ViewMain from './views/Index.vue'
import type { ApiInstallParam } from 'z-decorator/src/api'

import './assets/style.scss'

const profileStore = useProfileStore()
const { ACCESS_TOKEN_HEADER_KEY, REFRESH_TOKEN_HEADER_KEY } = Constant

const app = createApp(App)

const ajaxErrorHandlerMap: ApiInstallParam['errorHandlerMap'] = {
  401: () => {
    profileStore.clear()
  },
  408: (error) => {
    ajaxErrorHandlerMap[401](error)
  },
  400: (error) => {
    ElNotification.error({
      title: '错误',
      message: error.message,
      position: 'bottom-right'
    })
  },
  500: (error) => {
    ajaxErrorHandlerMap[400](error)
  },
  599: (error) => {
    ajaxErrorHandlerMap[400](error)
  }
}

app.use(ZDecoratorView, {
  router,

  apiInstallerParam: {
    options: {
      baseURL: '/api'
    },
    requestIntercept: (requestConfig) => {
      const token = profileStore.tokenRef.value

      if (token) {
        requestConfig.headers[ACCESS_TOKEN_HEADER_KEY] = token.accessToken
        requestConfig.headers[REFRESH_TOKEN_HEADER_KEY] = token.refreshToken
      }

      return requestConfig
    },
    errorHandlerMap: ajaxErrorHandlerMap
  },

  iconMap: import.meta.glob('@/components/icons/**/*.vue', {
    eager: true,
    import: 'default'
  }),
  routeComponentMap: import.meta.glob('@/views/pages/**/*.vue', {
    import: 'default'
  }),
  rootComponent: ViewMain
})

// window._AMapSecurityConfig = {
//   // securityJsCode: 'b59e1df130419e2f4f57aeda62156286'
//   serviceHost: `${location.origin}/_AMapService`
// }

app.mount('#app')
