import { Constant } from '@/models/Constant'
import { shallowRef } from 'vue'
import type { ProfileProps } from 'z-decorator-view/src/components/Layout/Profile/Profile.vue'

// 开始：用户信息令牌
export interface TokenInfo {
  accessToken: string
  refreshToken: string
}
const { LOCALE_TOKEN_TOKEN_KEY, TOKEN_PREFIX } = Constant
let token = localStorage.getItem(LOCALE_TOKEN_TOKEN_KEY)
try {
  if (token !== null) {
    token = JSON.parse(token)
  }
} catch (error) {
  console.error(error)
}
const tokenRef = shallowRef<TokenInfo | null>(typeof token === 'object' ? token : null)
const setToken = (token: TokenInfo) => {
  localStorage.setItem(
    LOCALE_TOKEN_TOKEN_KEY,
    JSON.stringify(
      (tokenRef.value = {
        accessToken: `${TOKEN_PREFIX}${token.accessToken}`,
        refreshToken: `${TOKEN_PREFIX}${token.refreshToken}`
      })
    )
  )
}
const clearToken = () => {
  tokenRef.value = null
  localStorage.removeItem(LOCALE_TOKEN_TOKEN_KEY)
}
// 结束：用户信息令牌

// 开始：用户个人信息
export type ProfileInfo = Omit<ProfileProps, 'menuMap'>
const profileInfoRef = shallowRef<ProfileInfo | null>(null)
const setProfileInfo = (profileInfo: ProfileInfo) => {
  profileInfoRef.value = profileInfo
}
const clearProfileInfo = () => {
  profileInfoRef.value = null
}
// 结束：用户人人信息

const response = {
  tokenRef,
  setToken,
  clearToken,

  profileInfoRef,
  setProfileInfo,
  clearProfileInfo,

  clear: () => {
    clearToken()
    clearProfileInfo()
  }
}

export const useProfileStore = () => response
